@@ -3,21 +3,18 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.2 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.  
+ * Please see the License for the specific language governing rights and 
  * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
@@ -64,8 +61,7 @@ class AppleUSBHub : public IOService
     IOUSBPipe * 		_interruptPipe;
     IOBufferMemoryDescriptor *	_buffer;
     IOCommandGate *		_gate;
-    IOWorkLoop *		_workLoop;
-    UInt32			_locationID;
+
     UInt32			_inStartMethod;
     bool			_portSuspended;
     bool			_hubHasBeenDisconnected;
@@ -145,12 +141,12 @@ class AppleUSBHub : public IOService
     void 		PrintHubDescriptor(IOUSBHubDescriptor *desc);
 
     void 		FatalError(IOReturn err, char *str);
+    void 		DisplayNotEnoughPowerNotice();
     IOReturn		DoPortAction(UInt32 type, UInt32 portNumber, UInt32 options );
     void		StartWatchdogTimer();
     void		StopWatchdogTimer();
     IOReturn		RearmInterruptRead();
     void		ResetMyPort();
-
     IOUSBHubDescriptor 	GetCachedHubDescriptor() { return _hubDescriptor; }
     
 public:
